import os
import pytest
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart

import wcs.qommon.ctl
from wcs.ctl.collectstatic import CmdCollectStatic
from wcs.ctl.process_bounce import CmdProcessBounce

from utilities import create_temporary_pub, clean_temporary_pub

@pytest.fixture
def pub():
    return create_temporary_pub()

def teardown_module(module):
    clean_temporary_pub()

def test_loading():
    ctl = wcs.qommon.ctl.Ctl(cmd_prefixes=['wcs.ctl'])
    ctl.load_all_commands(ignore_errors=False)
    assert 'start' in ctl.get_commands().keys()

def test_collectstatic(pub):
    CmdCollectStatic.collectstatic(pub)
    assert os.path.exists(os.path.join(pub.app_dir, 'collectstatic', 'css', 'wcs.css'))
    assert os.path.exists(os.path.join(pub.app_dir, 'collectstatic', 'css', 'qommon.css'))
    assert os.path.exists(os.path.join(pub.app_dir, 'collectstatic', 'css', 'gadjo.css'))
    assert os.path.exists(os.path.join(pub.app_dir, 'collectstatic', 'xstatic', 'jquery.js'))
    CmdCollectStatic.collectstatic(pub, clear=True, link=True)
    assert os.path.islink(os.path.join(pub.app_dir, 'collectstatic', 'css', 'wcs.css'))

def test_get_bounce_addrs():
    msg = MIMEText('Hello world')
    assert CmdProcessBounce.get_bounce_addrs(msg) is None

    msg = MIMEMultipart(_subtype='mixed')
    msg.attach(MIMEText('Hello world'))
    msg.attach(MIMEText('<p>Hello world</p>', _subtype='html'))
    assert CmdProcessBounce.get_bounce_addrs(msg) is None

    msg = MIMEText('Hello world')
    msg['x-failed-recipients'] = 'foobar@localhost'
    assert CmdProcessBounce.get_bounce_addrs(msg) == ['foobar@localhost']

    msg = MIMEText('''failed addresses follow:
                      foobar@localhost
                      message text follows:''')
    assert CmdProcessBounce.get_bounce_addrs(msg) == ['foobar@localhost']
